%define use_systemd (0%{?fedora} && 0%{?fedora} >= 18) || (0%{?rhel} && 0%{?rhel} >= 7)

Name:           virt-who
Version:        0.17
Release:        9%{?dist}
Summary:        Agent for reporting virtual guest IDs to subscription-manager

License:        GPLv2+
URL:            https://fedorahosted.org/virt-who/
Source0:        https://fedorahosted.org/releases/v/i/virt-who/%{name}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  python-setuptools
BuildRequires:  python2-devel
Requires:       python-setuptools
Requires:       libvirt-python
# python-rhsm 1.10.10 has support for sending additional information together with guest uuids
Requires:       python-rhsm >= 1.10.10
# python-suds is required for vSphere support
Requires:       python-suds
# m2crypto is required for Hyper-V support
Requires:       m2crypto
# for journal logging
Requires:       python-requests
# systemd stuff
%if %{use_systemd}
Requires: systemd-python
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires: systemd
%else
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts
%endif

# Support prefix in the rhevm url
Patch0:         virt-who-0.17-support-prefix-in-rhevm-url.patch
# raise exception when status code is not 200 in rhevm
Patch1:         virt-who-0.17-rhevm-raise-exception-when-code-is-not-200.patch
# Support new api for socket count in rhevm-4.0
Patch2:         virt-who-0.17-rhevm-socket-count-new-api.patch
# sam: handle connection interruption in ping method
Patch3:         virt-who-0.17-handle-ping-interruption-in-sam.patch
# esx: skip cert verification when downloading vim file
Patch4:         virt-who-0.17-esx-skip-cert-verification-for-vim-file.patch
# Don't show error when requests are too old
Patch5:         virt-who-0.17-supress-requests-error.patch
# esx: fix using of connection timeout
Patch6:         virt-who-0.17-fix-esx-timeouts.patch
# rhevm: fix urls not ending with slash
Patch7:         virt-who-0.17-rhevm-fix-urls-without-slash.patch
# xen: fix support for multiple hosts
Patch8:         virt-who-0.17-xen-fix-multiple-host-support.patch
# Add placeholders for xen config to /etc/sysconfig/virt-who template
Patch9:         virt-who-0.17-xen-placeholders-in-sysconfig.patch
# Handle errors when checking job status
Patch10:        virt-who-0.17-handle-error-when-checking-job-status.patch
# Allow quoted config values
Patch11:        virt-who-0.17-allow-quoted-config-values.patch
# Use sha256 instead of md5 for internal object hashing
Patch12:        virt-who-0.17-use-sha256-instead-of-md5.patch
# sat5: create and use hypervisor-base channel for new system registration
Patch13:        virt-who-0.17-create-and-use-hypervisor-base-channel.patch
# Support new status format in rhevm 4.0
Patch14:        virt-who-0.17-rhevm-support-new-status-format.patch
# esx: don't add dot to hostname when there is no domain
Patch15:        virt-who-0.17-esx-dont-add-dot-to-hostname.patch
# config: fix unquoting list of options
Patch16:        virt-who-0.17-fix-unqouting-list-of-options.patch
# print: show hypervisor facts in print mode
Patch17:        virt-who-0.17-show-hypervisor-facts-in-print-mode.patch
# virt: don't show failures when backend is being terminated
Patch18:        virt-who-0.17-dont-show-failures-when-terminated.patch
# sat5: don't send unchanged reports
Patch19:        virt-who-0.17-sat5-dont-send-unchanged-reports


%description
Agent that collects information about virtual guests present in the system and
report them to the subscription manager.

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1

%build
%if %{use_systemd}
%{__python2} setup.py build
%else
%{__python} setup.py build
%endif


%install
%if %{use_systemd}
%{__python2} setup.py install --root %{buildroot}
%{__python2} setup.py install_config --root %{buildroot}
%{__python2} setup.py install_man_pages --root %{buildroot}
%{__python2} setup.py install_systemd --root %{buildroot}
%else
%{__python} setup.py install --root %{buildroot}
%{__python} setup.py install_config --root %{buildroot}
%{__python} setup.py install_upstart --root %{buildroot}

# setup.py doesn't correctly install the man pages on EL6
%{__mkdir_p} %{buildroot}/%{_mandir}/man5
%{__mkdir_p} %{buildroot}/%{_mandir}/man8
%{__gzip} -c virt-who.8 > %{buildroot}/%{_mandir}/man8/virt-who.8.gz
%{__gzip} -c virt-who-password.8 > %{buildroot}/%{_mandir}/man8/virt-who-password.8.gz
%{__gzip} -c virt-who-config.5 > %{buildroot}/%{_mandir}/man5/virt-who-config.5.gz

%endif

mkdir -p %{buildroot}/%{_sharedstatedir}/%{name}/
touch %{buildroot}/%{_sharedstatedir}/%{name}/key

# Don't run test suite in check section, because it need the system to be
# registered to subscription-manager server

%post
%if %{use_systemd}
%systemd_post virt-who.service
%else
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add virt-who
%endif

%preun
%if %{use_systemd}
%systemd_preun virt-who.service
%else
if [ $1 -eq 0 ] ; then
    /sbin/service virt-who stop >/dev/null 2>&1
    /sbin/chkconfig --del virt-who
fi
%endif

%postun
%if %{use_systemd}
%systemd_postun_with_restart virt-who.service
%else
if [ "$1" -ge "1" ] ; then
    /sbin/service virt-who condrestart >/dev/null 2>&1 || :
fi
%endif

%files
%doc README.md README.hyperv LICENSE
%{_bindir}/virt-who
%{_bindir}/virt-who-password
%{python_sitelib}/*
%if %{use_systemd}
%{_unitdir}/virt-who.service
%else
%{_sysconfdir}/rc.d/init.d/virt-who
%endif
%{_sysconfdir}/virt-who.conf
%attr(700, root, root) %dir %{_sysconfdir}/virt-who.d
%{_sysconfdir}/virt-who.d/template.conf
%attr(600, root, root) %config(noreplace) %{_sysconfdir}/sysconfig/virt-who
%{_mandir}/man8/virt-who.8.gz
%{_mandir}/man8/virt-who-password.8.gz
%{_mandir}/man5/virt-who-config.5.gz
%attr(700, root, root) %{_sharedstatedir}/%{name}
%ghost %{_sharedstatedir}/%{name}/key

%changelog
* Thu Aug 04 2016 Eric D Helms <ericdhelms@gmail.com> 0.17-9
- Fix permissions on virt-who (ericdhelms@gmail.com)

* Wed Aug 03 2016 Eric D Helms <ericdhelms@gmail.com> 0.17-8
- Automatic commit of package [virt-who] minor release [0.17-7].
  (ericdhelms@gmail.com)
- Add virt-who 0.17-7 (ericdhelms@gmail.com)

* Wed Aug 03 2016 Eric D Helms <ericdhelms@gmail.com> 0.17-7
- new package built with tito

* Wed Jul 27 2016 Radek Novacek <rnovacek@redhat.com> - 0.17-7
- esx: don't add dot to hostname when there is no domain
- config: fix unquoting list of options
- print: show hypervisor facts in print mode
- virt: don't show failures when backend is being terminated
- sat5: don't send unchanged reports
- Resolves: rhbz#1339863, rhbz#1359640, rhbz#1359653, rhbz#1359571

* Thu Jul 14 2016 Radek Novacek <rnovacek@redhat.com> - 0.17-6
- Support new status format in rhevm 4.0
- Resolves: rhbz#1353074

* Thu Jun 30 2016 Radek Novacek <rnovacek@redhat.com> 0.17-5
- Apply the patches from -4
- Resolves: rhbz#1245035

* Thu Jun 30 2016 Radek Novacek <rnovacek@redhat.com> 0.17-4
- Use sha256 instead of md5 for internal object hashing
- sat5: create and use hypervisor-base channel for new system registration
- Resolves: rhbz#1245035

* Thu Jun 23 2016 Radek Novacek <rnovacek@redhat.com> 0.17-3
- Don't show error when requests are too old
- esx: fix using of connection timeout
- rhevm: fix urls not ending with slash
- xen: fix support for multiple hosts
- Add placeholders for xen config to /etc/sysconfig/virt-who template
- Handle errors when checking job status
- Allow quoted config values
- Resolves: rhbz#1263512, rhbz#1311632, rhbz#1342364, rhbz#1346548, rhbz#1346577

* Tue May 31 2016 Radek Novacek <rnovacek@redhat.com> 0.17-2
- Support prefix in the rhevm url
- Raise exception when status code is not 200 in rhevm
- Support new api for socket count in rhevm-4.0
- SAM: handle connection interruption in ping method
- ESX: skip cert verification when downloading vim file
- Add python-setuptools requirement
- Resolves: rhbz#1337407, rhbz#1337757, rhbz#1337758, rhbz#1338596, rhbz#1339419

* Tue May 17 2016 Radek Novacek <rnovacek@redhat.com> 0.17-1
- Rebase to 0.17
- Resolves: rhbz#1291737

* Tue Sep 22 2015 Radek Novacek <rnovacek@redhat.com> 0.14-9
- Check config option
- Another attempt on hyperv proxy support
- Resolves: rhbz#1254843, rhbz#1250782

* Tue Sep 15 2015 Radek Novacek <rnovacek@redhat.com> 0.14-8
- Fix logging of fatal errors
- Change systemd unit type to notify
- Warn about usage of env and owner in non-remote libvirt mode
- Fix proxy support in ESX and Hyper-V modes
- Resolves: rhbz#1254843, rhbz#1243341, rhbz#1250782

* Tue Sep 01 2015 Radek Novacek <rnovacek@redhat.com> 0.14-7
- Add a warning that password auth is not supported on remote libvirt
- Resolves: rhbz#1258726

* Thu Aug 27 2015 Radek Novacek <rnovacek@redhat.com> 0.14-6
- virt: don't enqueue error reports when no error occurs
- Config: show warning when unapplicable option is used
- fake: check if fake data are correct
- Resolves: rhbz#1257073

* Tue Aug 25 2015 Radek Novacek <rnovacek@redhat.com> 0.14-5
- Use systemd notify for service status updates
- Add template configuration file
- Allow single quotes and spaces in config lists
- Fail if no owner or env is set in SAM mode
- Clear obsolete reports before sending them
- Resolves: rhbz#1243341, rhbz#1250159, rhbz#1254840

* Tue Aug 18 2015 Radek Novacek <rnovacek@redhat.com> 0.14-4
- Readd support for hypervisorType guest attribute
- hyperv: add proxy support
- Set active attribute to 1 when guest is suspended
- hyperv: consider Quiesce EnabledState as paused state
- Remove -b option completely
- Fake: fix non-hypervisor reporting
- Resolves: rhbz#1248360

* Thu Jul 30 2015 Radek Novacek <rnovacek@redhat.com> 0.14-3
- Put uuid before guests in print mode for better readibility
- Fix decoding saved association in fake mode
- Stop the main loop when fatal error occurs
- Deprecate -b option and VIRTWHO_BACKGROUND env var
- Support hypervisor_id=hostname in remote libvirt
- Fix host uuid filtering
- Resolves: rhbz#1243683, rhbz#1167238, rhbz#1247066, rhbz#1247031, rhbz#1246409, rhbz#1246951, rhbz#1247922, rhbz#1247922, rhbz#1248425

* Thu Jul 16 2015 Radek Novacek <rnovacek@redhat.com> 0.14-2
- Support asynchronous API in candlepin
- Nicely order keys in debug report
- Retry sending data multiple times
- Resolves: rhbz#1240728, rhbz#1243697 

* Tue Jun 23 2015 Radek Novacek <rnovacek@redhat.com> 0.14-1
- Rebase to virt-who-0.14
- Resolves: rhbz#1200374

* Fri Nov 28 2014 Radek Novacek <rnovacek@redhat.com> 0.11-5
- Limit systemd service shutdown to 5 seconds
- Fix error in domain sorting
- Satellite: use proper hypervisor type in VM name
- Resolves: rhbz#1161434, rhbz#1168111, rhbz#1168122

* Thu Nov 13 2014 Radek Novacek <rnovacek@redhat.com> 0.11-4
- Fix ecrypted passwords
- Remove syslog.target from systemd unit After definition
- Fix missing config attribute of the Esx object
- Resolves: rhbz#1161607, rhbz#1162049, rhbz#1163021

* Wed Nov 05 2014 Radek Novacek <rnovacek@redhat.com> 0.11-3
- Treat remove libvirt as hypervisor
- Set /etc/sysconfig/virt-who permissions to 600
- Create /etc/virt-who.d directory
- Fix wrong options used when connecting to satellite
- Display found configurations and their modes in the log file
- Resolves: rhbz#1127965, rhbz#1158759, rhbz#1159187, rhbz#1158859, rhbz#1158803

* Tue Oct 14 2014 Radek Novacek <rnovacek@redhat.com> 0.11-2
- Add support for remote libvirt connections
- Resolves: rhbz#1127965

* Mon Sep 08 2014 Radek Novacek <rnovacek@redhat.com> 0.11-1
- Rebase to 0.11
- Resolves: rhbz#1122489

* Fri Jan 10 2014 Radek Novacek <rnovacek@redhat.com> 0.8-12
- Support sending additional information together with guest uuid on libvirt
- Reconnect to vsphere before each scan
- Requires python-rhsm >= 1.10.10
- Resolves: rhbz#1048954, rhbz#1047245

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 0.8-11
- Mass rebuild 2013-12-27

* Wed Dec 11 2013 Radek Novacek <rnovacek@redhat.com> 0.8-10
- Force using background mode when starting from systemd
- Check if process defined by PID file exists
- vsphere: reconnect before each scan
- Resolves: rhbz#1036561, rhbz#1035604, rhbz#1035957

* Thu Nov 21 2013 Radek Novacek <rnovacek@redhat.com> 0.8-9
- Add satellite support
- Handle more than 100 objects in esx traversal
- Use instanceUuid when uuid of virtual machine is empty
- Resolves: rhbz#1032596

* Fri Jun 14 2013 Radek Novacek <rnovacek@redhat.com> 0.8-8
- Increase ESXi compatibility
- Resolves: rhbz#923760

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov 27 2012 Radek Novacek <rnovacek@redhat.com> 0.8-6
- Add systemd support
- specfile cleanup

* Thu Oct 25 2012 Radek Novacek <rnovacek@redhat.com> 0.8-5
- Fix adding https:// to ESX url

* Wed Oct 24 2012 Radek Novacek <rnovacek@redhat.com> 0.8-4
- Help and manpage improvements

* Wed Oct 17 2012 Radek Novacek <rnovacek@redhat.com> 0.8-3
- Fix bugs in Hyper-V support (patch rebased)
- Create PID file ASAP to prevent service stop fails

* Thu Oct 11 2012 Radek Novacek <rnovacek@redhat.com> 0.8-2
- Add support for accessing Hyper-V

* Wed Sep 26 2012 Radek Novacek <rnovacek@redhat.com> 0.8-1
- Upstream version 0.8
- RFE: command line improvements
- Add support for accessing RHEV-M
- Fix printing tracebacks on terminal

* Thu Apr 26 2012 Radek Novacek <rnovacek@redhat.com> 0.6-6
- Handle unknown libvirt event properly

* Wed Apr 18 2012 Radek Novacek <rnovacek@redhat.com> 0.6-5
- Enable debug output to be written to stderr
- Log guest list to log even in non-debug mode

* Tue Apr 17 2012 Radek Novacek <rnovacek@redhat.com> 0.6-4
- Fix regression in double fork patch

* Wed Mar 28 2012 Radek Novacek <rnovacek@redhat.com> 0.6-3
- Do double fork when daemon is starting

* Fri Mar 09 2012 Radek Novacek <rnovacek@redhat.com> 0.6-2
- Add python-suds require
- Requires python-rhsm >= 0.98.6

* Thu Mar 01 2012 Radek Novacek <rnovacek@redhat.com> 0.6-1
- Rebase to virt-who-0.6

* Wed Oct 12 2011 Radek Novacek <rnovacek@redhat.com> 0.3-3
- Use updateConsumer API instead of updateConsumerFact (fixes limit 255 chars of uuid list)
- Requires python-rhsm >= 0.96.13 

* Wed Sep 07 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-2
- Add upstream patch that prevents failure when server not implements /status/ command

* Thu Sep 01 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-1
- Add initscript and configuration file

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-2
- Bump release because of tagging in wrong branch

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-1
- Update to upstream version 0.2
- Add Requires: libvirt

* Fri Aug 19 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-2
- Add BuildRoot tag (the package will be in RHEL5)

* Wed Aug 10 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-1
- initial import
